@@ -9,13 +9,16 @@ except (ImportError, RuntimeError):  # pragma: nocover
         from PyQt4.QtCore import QObject, QTimer
     except ImportError:
         try:
-            from PySide2.QtCore import QObject, QTimer  # noqa
+            from PySide6.QtCore import QObject, QTimer  # noqa
         except ImportError:
             try:
-                from PySide.QtCore import QObject, QTimer  # noqa
+                from PySide2.QtCore import QObject, QTimer  # noqa
             except ImportError:
-                raise ImportError('QtScheduler requires either PyQt5, PyQt4, PySide2 '
-                                  'or PySide installed')
+                try:
+                    from PySide.QtCore import QObject, QTimer  # noqa
+                except ImportError:
+                    raise ImportError('QtScheduler requires either PyQt5, PyQt4, PySide6, PySide2 '
+                                      'or PySide installed')
 
 
 class QtScheduler(BaseScheduler):
@@ -30,7 +33,7 @@ class QtScheduler(BaseScheduler):
     def _start_timer(self, wait_seconds):
         self._stop_timer()
         if wait_seconds is not None:
-            wait_time = min(wait_seconds * 1000, 2147483647)
+            wait_time = min(int(wait_seconds * 1000), 2147483647)
             self._timer = QTimer.singleShot(wait_time, self._process_jobs)
 
     def _stop_timer(self):
